@@ -7,7 +7,15 @@ import nox
 
 PYTHON_ALL_VERSIONS = ["3.12", "3.11", "3.10", "3.9", "3.8"]
 PYTHON_DEFAULT_VERSION = "3.12"
-DOC_DEPENDENCIES = ["jinja2", "mkdocs", "mkdocs-material", "mkdocs-gen-files", "mkdocs-macros-plugin", "towncrier"]
+DOC_DEPENDENCIES = [
+    "jinja2",
+    "mkdocs",
+    "mkdocs-material",
+    "mkdocs-gen-files",
+    "mkdocs-macros-plugin",
+    "towncrier",
+    "markdown-gfm-admonition",
+]
 MAN_DEPENDENCIES = ["argparse-manpage[setuptools]"]
 TEST_DEPENDENCIES = ["pytest", "pypiserver[passlib]", 'setuptools; python_version>="3.12"', "pytest-cov"]
 # Packages whose dependencies need an intact system PATH to compile
@@ -133,7 +141,9 @@ def build_docs(session: nox.Session) -> None:
     session.run("mkdocs", "build", "--strict", "--site-dir", *site_dir)
     upcoming_changelog.unlink(missing_ok=True)
     for site in site_dir:
-        shutil.rmtree(Path(site, "_draft_changelog"))
+        draft_changelog_dir = Path(site, "_draft_changelog")
+        if draft_changelog_dir.exists():
+            shutil.rmtree(draft_changelog_dir)
 
 
 @nox.session(python=PYTHON_DEFAULT_VERSION)
@@ -144,6 +154,12 @@ def watch_docs(session: nox.Session) -> None:
     upcoming_changelog.unlink(missing_ok=True)
 
 
+@nox.session(python=PYTHON_DEFAULT_VERSION)
+def build_changelog(session: nox.Session) -> None:
+    session.install(*DOC_DEPENDENCIES, ".")
+    session.run("towncrier", "build", "--version", session.posargs[0], "--yes")
+
+
 @nox.session(python=PYTHON_DEFAULT_VERSION)
 def build_man(session: nox.Session) -> None:
     session.install(*MAN_DEPENDENCIES, ".")
