@@ -1,20 +1,24 @@
 from pipx.commands.ensure_path import ensure_pipx_paths
 from pipx.commands.environment import environment
 from pipx.commands.inject import inject
-from pipx.commands.install import install
+from pipx.commands.install import install, install_all
+from pipx.commands.interpreter import list_interpreters, prune_interpreters, upgrade_interpreters
 from pipx.commands.list_packages import list_packages
+from pipx.commands.pin import pin, unpin
 from pipx.commands.reinstall import reinstall, reinstall_all
 from pipx.commands.run import run
 from pipx.commands.run_pip import run_pip
 from pipx.commands.uninject import uninject
 from pipx.commands.uninstall import uninstall, uninstall_all
-from pipx.commands.upgrade import upgrade, upgrade_all
+from pipx.commands.upgrade import upgrade, upgrade_all, upgrade_shared
 
 __all__ = [
     "upgrade",
     "upgrade_all",
+    "upgrade_shared",
     "run",
     "install",
+    "install_all",
     "inject",
     "uninject",
     "uninstall",
@@ -25,4 +29,9 @@ __all__ = [
     "run_pip",
     "ensure_pipx_paths",
     "environment",
+    "list_interpreters",
+    "prune_interpreters",
+    "pin",
+    "unpin",
+    "upgrade_interpreters",
 ]
