@@ -2,7 +2,7 @@ import sys
 from io import BytesIO, TextIOWrapper
 from unittest import mock
 
-import pytest  # type: ignore
+import pytest  # type: ignore[import-not-found]
 
 from pipx.emojis import use_emojis
 
@@ -16,7 +16,7 @@ from pipx.emojis import use_emojis
         ("0", "utf-8", False),
         ("1", "utf-8", True),
         ("true", "utf-8", True),
-        ("tru", "utf-8", False),
+        ("tru", "utf-8", False),  # codespell:ignore tru
         ("True", "utf-8", True),
         ("false", "utf-8", False),
         # latin_1 (alias: iso-8859-1)
@@ -25,7 +25,7 @@ from pipx.emojis import use_emojis
         ("0", "latin_1", False),
         ("1", "latin_1", True),
         ("true", "latin_1", True),
-        ("tru", "latin_1", False),
+        ("tru", "latin_1", False),  # codespell:ignore tru
         ("True", "latin_1", True),
         ("false", "latin_1", False),
         # cp1252
@@ -34,7 +34,7 @@ from pipx.emojis import use_emojis
         ("0", "cp1252", False),
         ("1", "cp1252", True),
         ("true", "cp1252", True),
-        ("tru", "cp1252", False),
+        ("tru", "cp1252", False),  # codespell:ignore tru
         ("True", "cp1252", True),
         ("false", "cp1252", False),
     ],
